@@ -24,6 +24,18 @@ module Fog
       Fog::Formatador.format(self)
     end
 
+    def ==(o)
+      unless o.is_a?(Fog::Model)
+        super
+      else
+        if (o.identity.nil? and self.identity.nil?)
+          o.object_id == self.object_id
+        else
+          o.class == self.class and o.identity == self.identity
+        end
+      end
+    end
+
     def reload
       requires :identity
 
@@ -52,7 +64,7 @@ module Fog
       end
     end
 
-    def wait_for(timeout = Fog.timeout, interval = 1, &block)
+    def wait_for(timeout = Fog.timeout, interval = Fog.interval, &block)
       reload_has_succeeded = false
       duration = Fog.wait_for(timeout, interval) do # Note that duration = false if it times out
         if reload
